@@ -60,6 +60,8 @@ class VulnerabilityNote(proto.Message):
             the source. This is an upstream timestamp from
             the underlying information source - e.g. Ubuntu
             security tracker.
+        cvss_version (grafeas.grafeas_v1.types.CVSSVersion):
+            CVSS version used to populate cvss_score and severity.
     """
 
     class Detail(proto.Message):
@@ -281,6 +283,11 @@ class VulnerabilityNote(proto.Message):
         number=6,
         message=timestamp_pb2.Timestamp,
     )
+    cvss_version = proto.Field(
+        proto.ENUM,
+        number=7,
+        enum=cvss.CVSSVersion,
+    )
 
 
 class VulnerabilityOccurrence(proto.Message):
@@ -331,6 +338,9 @@ class VulnerabilityOccurrence(proto.Message):
         fix_available (bool):
             Output only. Whether at least one of the
             affected packages has a fix available.
+        cvss_version (grafeas.grafeas_v1.types.CVSSVersion):
+            Output only. CVSS version used to populate cvss_score and
+            severity.
     """
 
     class PackageIssue(proto.Message):
@@ -466,6 +476,11 @@ class VulnerabilityOccurrence(proto.Message):
         proto.BOOL,
         number=9,
     )
+    cvss_version = proto.Field(
+        proto.ENUM,
+        number=11,
+        enum=cvss.CVSSVersion,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
